@@ -23,7 +23,14 @@ from .gui.class_gui import (
     ToolBoxClassGui,
     ListClassGui,
 )
-from .gui._base import PopUpMode, ErrorMode, defaults, MagicTemplate, check_override
+from .gui._base import (
+    PopUpMode,
+    ErrorMode,
+    defaults,
+    MagicTemplate,
+    check_override,
+    convert_attributes,
+)
 from .gui import ContextMenuGui, MenuGui, ToolBarGui
 from ._app import get_app
 from .types import WidgetType
@@ -32,6 +39,7 @@ from . import _register  # activate type registration things.
 if TYPE_CHECKING:
     from .stylesheets import StyleSheet
     from .gui import MenuGuiBase
+    from .gui._function_gui import FunctionGuiPlus
     from .types import WidgetTypeStr, PopUpModeStr, ErrorModeStr
     from .help import HelpWidget
 
@@ -146,8 +154,9 @@ def magicclass(
         mod = cls.__module__
         qualname = cls.__qualname__
 
+        new_attrs = convert_attributes(cls, hide=class_gui.__mro__)
         oldclass = type(cls.__name__ + _BASE_CLASS_SUFFIX, (cls,), {})
-        newclass = type(cls.__name__, (class_gui, oldclass), {})
+        newclass = type(cls.__name__, (class_gui, oldclass), new_attrs)
 
         newclass.__signature__ = sig
         newclass.__doc__ = doc
@@ -160,9 +169,8 @@ def magicclass(
 
         @functools_wraps(oldclass.__init__)
         def __init__(self: MagicTemplate, *args, **kwargs):
-            app = (
-                get_app()
-            )  # Without "app = " Jupyter freezes after closing the window!
+            # Without "app = " Jupyter freezes after closing the window!
+            app = get_app()
 
             class_gui.__init__(
                 self,
@@ -175,22 +183,26 @@ def magicclass(
                 name=name or cls.__name__,
                 visible=visible,
             )
-            super(oldclass, self).__init__(*args, **kwargs)
-            self._convert_attributes_into_widgets()
-            if hasattr(self, "__post_init__"):
-                self.__post_init__()
-
-            if widget_type in (WidgetType.collapsible, WidgetType.button):
-                self.text = self.name
-
+            # prepare macro
             macrowidget = self.macro.widget.native
             macrowidget.setParent(self.native, macrowidget.windowFlags())
             self.macro.widget.__magicclass_parent__ = self
 
+            with self.macro.blocked():
+                super(oldclass, self).__init__(*args, **kwargs)
+
+            self._convert_attributes_into_widgets()
+
+            if widget_type in (WidgetType.collapsible, WidgetType.button):
+                self.text = self.name
+
             if icon_path:
                 self.icon_path = icon_path
             if stylesheet:
                 self.native.setStyleSheet(str(stylesheet))
+            if hasattr(self, "__post_init__"):
+                with self.macro.blocked():
+                    self.__post_init__()
 
         newclass.__init__ = __init__
 
@@ -401,8 +413,9 @@ def _call_magicmenu(
         mod = cls.__module__
         qualname = cls.__qualname__
 
+        new_attrs = convert_attributes(cls, hide=menugui_class.__mro__)
         oldclass = type(cls.__name__ + _BASE_CLASS_SUFFIX, (cls,), {})
-        newclass = type(cls.__name__, (menugui_class, oldclass), {})
+        newclass = type(cls.__name__, (menugui_class, oldclass), new_attrs)
 
         newclass.__signature__ = sig
         newclass.__doc__ = doc
@@ -411,9 +424,8 @@ def _call_magicmenu(
 
         @functools_wraps(oldclass.__init__)
         def __init__(self: MagicTemplate, *args, **kwargs):
-            app = (
-                get_app()
-            )  # Without "app = " Jupyter freezes after closing the window!
+            # Without "app = " Jupyter freezes after closing the window!
+            app = get_app()
 
             menugui_class.__init__(
                 self,
@@ -424,18 +436,22 @@ def _call_magicmenu(
                 labels=labels,
                 name=name or cls.__name__,
             )
-            super(oldclass, self).__init__(*args, **kwargs)
-            self._convert_attributes_into_widgets()
-            if hasattr(self, "__post_init__"):
-                self.__post_init__()
-
-            if icon_path:
-                self.icon_path = icon_path
 
             macrowidget = self.macro.widget.native
             macrowidget.setParent(self.native, macrowidget.windowFlags())
             self.macro.widget.__magicclass_parent__ = self
 
+            with self.macro.blocked():
+                super(oldclass, self).__init__(*args, **kwargs)
+
+            self._convert_attributes_into_widgets()
+
+            if icon_path:
+                self.icon_path = icon_path
+            if hasattr(self, "__post_init__"):
+                with self.macro.blocked():
+                    self.__post_init__()
+
         newclass.__init__ = __init__
 
         # Users may want to override repr
@@ -479,6 +495,32 @@ def build_help(ui: MagicTemplate, parent=None) -> HelpWidget:
     return help_widget
 
 
+def get_function_gui(ui: MagicTemplate, name: str) -> FunctionGuiPlus:
+    """
+    Get the FunctionGui object hidden beneath push button or menu.
+
+    This function is a helper function for magicclass.
+
+    Parameters
+    ----------
+    ui : MagicTemplate
+        Any of a magic-class instance.
+    name : str
+        Name of method (or strictly speaking, the name of PushButton).
+
+    Returns
+    -------
+    FunctionGuiPlus
+        FunctionGui object.
+    """
+    widget = ui[name]
+    if not hasattr(widget, "mgui"):
+        raise TypeError(f"Widget {widget} does not have FunctionGui inside it.")
+    if widget.mgui is None:
+        widget.changed()
+    return widget.mgui
+
+
 class Parameters:
     def __init__(self):
         self.__name__ = self.__class__.__name__
