@@ -15,9 +15,7 @@ if TYPE_CHECKING:
 
 
 class MacroEdit(FreeWidget):
-    """
-    A text edit embeded with a custom menu bar.
-    """
+    """A text edit embeded with a custom menu bar."""
 
     count = 0
 
@@ -297,9 +295,10 @@ class MacroEdit(FreeWidget):
 
 
 class GuiMacro(Macro):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self, max_lines: int, flags={}):
+        super().__init__(flags=flags)
         self._widget = None
+        self._max_lines = max_lines
         self.callbacks.append(self._update_widget)
 
     @property
@@ -313,9 +312,17 @@ class GuiMacro(Macro):
             self.append(Expr(Head.comment, [now.strftime("%Y/%m/%d %H:%M:%S")]))
         return self._widget
 
+    def copy(self) -> Macro:
+        """GuiMacro does not support deepcopy (and apparently _widget should not be copied)."""
+        from copy import deepcopy
+
+        return Macro(deepcopy(self.args), flags=self._flags)
+
     def _update_widget(self, expr=None):
         if self.widget.synchronize:
             self.widget.textedit.append(str(self.args[-1]))
+        if len(self) > self._max_lines:
+            del self[0]
 
     def _erase_last(self):
         if self.widget.synchronize:
