@@ -18,8 +18,14 @@ from ._base import (
     ErrorMode,
     value_widget_callback,
     nested_function_gui_callback,
+    _inject_recorder,
+)
+from .utils import (
+    copy_class,
+    define_callback,
+    MagicClassConstructionError,
+    set_context_menu,
 )
-from .utils import define_callback, MagicClassConstructionError, define_context_menu
 from ..widgets import (
     ButtonContainer,
     GroupBoxContainer,
@@ -124,6 +130,9 @@ class ClassGuiBase(BaseGui):
                     if not issubclass(attr, BaseGui):
                         continue
                     # Nested magic-class
+                    if cls.__name__ not in attr.__qualname__.split("."):
+                        attr = copy_class(attr)
+                        attr.__qualname__ = f"{cls.__qualname__}.{attr.__name__}"
                     widget = attr()
                     object.__setattr__(self, name, widget)
 
@@ -175,10 +184,7 @@ class ClassGuiBase(BaseGui):
 
                 elif isinstance(widget, ContextMenuGui):
                     # Add context menu to container
-                    self.native.setContextMenuPolicy(Qt.CustomContextMenu)
-                    self.native.customContextMenuRequested.connect(
-                        define_context_menu(widget, self.native)
-                    )
+                    set_context_menu(widget, self)
                     _hist.append((name, type(attr), "ContextMenuGui"))
 
                 elif isinstance(widget, ToolBarGui):
@@ -189,6 +195,7 @@ class ClassGuiBase(BaseGui):
                             self.native.addToolBar(self._toolbar)
                         else:
                             # self is not a main window object
+                            # TODO: these codes are too dirty...
                             if isinstance(self, _USE_OUTER_LAYOUT):
                                 _layout: QBoxLayout = self._widget._qwidget.layout()
                             else:
@@ -274,12 +281,6 @@ class ClassGuiBase(BaseGui):
                         f"\n{hist_str}\n\n{type(e).__name__}: {e}"
                     ) from e
 
-        # convert __call__ into a button
-        if hasattr(self, "__call__"):
-            widget = self._create_widget_from_method(self.__call__)
-            self._fast_insert(n_insert, widget)
-            n_insert += 1
-
         self._unify_label_widths()
         return None
 
@@ -335,7 +336,7 @@ def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiB
         def __getitem__(self, key):
             """Get item by integer, str, or slice."""
             if isinstance(key, str):
-                for widget in self:
+                for widget in self._list:
                     if key == widget.name:
                         return widget
             return container.__getattr__(self, key)
@@ -346,19 +347,23 @@ def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiB
             else:
                 object.__setattr__(self, name, value)
 
-        def _fast_insert(self: cls, key: int, widget: Widget | Callable) -> None:
-            if isinstance(widget, Callable):
+        def _fast_insert(self: cls, key: int, obj: Widget | Callable) -> None:
+            if isinstance(obj, Callable):
                 # Sometimes uses want to dynamically add new functions to GUI.
-                method_name = getattr(widget, "__name__", None)
-                if method_name and not hasattr(self, method_name):
-                    object.__setattr__(self, method_name, widget)
-
-                if isinstance(widget, FunctionGui):
-                    if widget.parent is None:
-                        f = nested_function_gui_callback(self, widget)
-                        widget.called.connect(f)
+                if isinstance(obj, FunctionGui):
+                    if obj.parent is None:
+                        f = nested_function_gui_callback(self, obj)
+                        obj.called.connect(f)
+                    widget = obj
                 else:
-                    widget = self._create_widget_from_method(widget)
+                    obj = _inject_recorder(obj, is_method=False).__get__(self)
+                    widget = self._create_widget_from_method(obj)
+
+                method_name = getattr(obj, "__name__", None)
+                if method_name and not hasattr(self, method_name):
+                    object.__setattr__(self, method_name, obj)
+            else:
+                widget = obj
 
             # _hide_labels should not contain Container because some ValueWidget like widgets
             # are Containers.
@@ -435,14 +440,17 @@ def make_gui(container: type[_C], no_margin: bool = True) -> type[_C | ClassGuiB
                     viewer.window._dock_widgets[name].show()
                 else:
                     dock = viewer.window.add_dock_widget(
-                        self, area="right", allowed_areas=["left", "right"]
+                        self,
+                        name=self.name.replace("_", " ").strip(),
+                        area="right",
+                        allowed_areas=["left", "right"],
                     )
                     dock.setFloating(self._popup_mode == PopUpMode.popup)
             else:
                 container.show(self, run=False)
                 self.native.activateWindow()
-            if run:
-                run_app()
+                if run:
+                    run_app()
             return None
 
         def reset_choices(self: cls, *_: Any):
