@@ -1,8 +1,11 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, Iterable, MutableSequence, Any
-from qtpy.QtWidgets import QTabWidget, QLineEdit, QMenu
+from typing import TYPE_CHECKING, Generic, Iterable, MutableSequence, Any, TypeVar
+from typing_extensions import _AnnotatedAlias, get_args
+from psygnal import Signal
+from qtpy.QtWidgets import QTabWidget, QLineEdit, QMenu, QVBoxLayout, QWidget
 from qtpy.QtGui import QTextCursor
 from qtpy.QtCore import Qt
+from magicgui.signature import split_annotated_type
 from magicgui.widgets import (
     PushButton,
     TextEdit,
@@ -12,11 +15,14 @@ from magicgui.widgets import (
     create_widget,
 )
 from magicgui.widgets._bases.value_widget import ValueWidget, UNSET
+from magicgui.backends._qtpy.widgets import QBaseWidget
 from .utils import FreeWidget, merge_super_sigs
 
 if TYPE_CHECKING:
     from qtpy.QtWidgets import QTextEdit
     from matplotlib.axes import Axes
+    from numpy.typing import ArrayLike
+    from superqt import QLabeledRangeSlider
 
 
 @merge_super_sigs
@@ -38,7 +44,7 @@ class OptionalWidget(Container):
 
     def __init__(
         self,
-        widget_type: type[ValueWidget] | None = None,
+        inner_widget: type[ValueWidget] | None = None,
         text: str = None,
         layout="vertical",
         nullable=True,
@@ -52,16 +58,21 @@ class OptionalWidget(Container):
             options = {}
         self._checkbox = CheckBox(text=text, value=True)
 
-        if widget_type is None:
+        if inner_widget is None:
+
+            annot = get_args(kwargs["annotation"])[0]
+
+            if isinstance(annot, _AnnotatedAlias):
+                annot, metadata = split_annotated_type(annot)
+                options.update(metadata)
+
             self._inner_value_widget = create_widget(
-                annotation=kwargs["annotation"],
+                annotation=annot,
                 options=options,
             )
+
         else:
-            self._inner_value_widget = create_widget(
-                widget_type=widget_type,
-                options=options,
-            )
+            self._inner_value_widget = inner_widget
 
         super().__init__(
             layout=layout,
@@ -182,11 +193,13 @@ class Figure(FreeWidget):
         self.draw()
         return self.ax
 
-    def hist(self, *args, **kwargs):
+    def hist(
+        self, *args, **kwargs
+    ) -> tuple[ArrayLike | list[ArrayLike], ArrayLike, list | list[list]]:
         """Copy of ``plt.hist``."""
-        self.ax.hist(*args, **kwargs)
+        out = self.ax.hist(*args, **kwargs)
         self.draw()
-        return self.ax
+        return out
 
     def text(self, *args, **kwargs):
         """Copy of ``plt.text``."""
@@ -194,6 +207,30 @@ class Figure(FreeWidget):
         self.draw()
         return self.ax
 
+    def quiver(self, *args, data=None, **kwargs):
+        """Copy of ``plt.quiver``."""
+        self.ax.quiver(*args, data=data, **kwargs)
+        self.draw()
+        return self.ax
+
+    def axline(self, xy1, xy2=None, *, slope=None, **kwargs):
+        """Copy of ``plt.axline``."""
+        self.ax.axline(xy1, xy2=xy2, slope=slope, **kwargs)
+        self.draw()
+        return self.ax
+
+    def axhline(self, y=0, xmin=0, xmax=1, **kwargs):
+        """Copy of ``plt.axhline``."""
+        self.ax.axhline(y, xmin, xmax, **kwargs)
+        self.draw()
+        return self.ax
+
+    def axvline(self, x=0, ymin=0, ymax=1, **kwargs):
+        """Copy of ``plt.axvline``."""
+        self.ax.axvline(x, ymin, ymax, **kwargs)
+        self.draw()
+        return self.ax
+
     def xlim(self, *args, **kwargs):
         """Copy of ``plt.xlim``."""
         ax = self.ax
@@ -325,6 +362,17 @@ class ConsoleTextEdit(TextEdit):
         cursor.deletePreviousChar()
         self.native.setTextCursor(cursor)
 
+    def erase_first(self):
+        """Erase the first line."""
+        cursor = self.native.textCursor()
+        cursor.movePosition(QTextCursor.Start)
+        cursor.select(QTextCursor.LineUnderCursor)
+        cursor.removeSelectedText()
+        cursor.movePosition(QTextCursor.Down)
+        cursor.deletePreviousChar()
+        cursor.movePosition(QTextCursor.End)
+        self.native.setTextCursor(cursor)
+
     @property
     def selected(self) -> str:
         """Return selected string."""
@@ -340,6 +388,130 @@ class CheckButton(PushButton):
         self.native.setCheckable(True)
 
 
+_V = TypeVar("_V")
+
+
+class QRangeSlider(QBaseWidget):
+    _qwidget: QLabeledRangeSlider
+
+    def _mgui_get_value(self):
+        pass
+
+    def _mgui_bind_change_callback(self, callback):
+        pass
+
+    def _mgui_set_value(self, rng):
+        pass
+
+
+class AbstractRangeSlider(ValueWidget, Generic[_V]):
+    """
+    A slider widget that represent a range like (2, 5).
+
+    This class is a temporary one and may be substituted by magicgui widget soon.
+    See https://github.com/napari/magicgui/pull/337.
+    """
+
+    changed = Signal(tuple)
+
+    def __init__(
+        self,
+        value=UNSET,
+        min=0,
+        max=1000,
+        orientation: str = "horizontal",
+        nullable: bool = True,
+        **kwargs,
+    ):
+        sl = self._construct_qt()
+        sl.setMinimum(min)
+        sl.setMaximum(max)
+        sl.valueChanged.connect(self.changed)
+        if orientation == "horizontal":
+            sl.setOrientation(Qt.Horizontal)
+        elif orientation == "vertical":
+            sl.setOrientation(Qt.Vertical)
+        else:
+            raise ValueError(
+                "Only horizontal and vertical orientation are currently supported"
+            )
+        self._slider = sl
+        super().__init__(
+            value=value,
+            widget_type=QRangeSlider,
+            backend_kwargs={"qwidg": QWidget},
+            **kwargs,
+        )
+        self.native.setLayout(QVBoxLayout())
+        self.native.setContentsMargins(0, 0, 0, 0)
+        self.native.layout().addWidget(sl)
+
+    @classmethod
+    def _construct_qt(cls, *args, **kwargs) -> QLabeledRangeSlider:
+        raise NotImplementedError()
+
+    @property
+    def value(self) -> tuple[_V, _V]:
+        return self._slider.value()
+
+    @value.setter
+    def value(self, rng: tuple[_V, _V]) -> None:
+        x0, x1 = rng
+        if x0 > x1:
+            raise ValueError(f"lower value exceeds higher value ({x0} > {x1}).")
+        self._slider.setValue((x0, x1))
+
+    @property
+    def range(self) -> tuple[_V, _V]:
+        return self._slider.minimum(), self._slider.maximum()
+
+    @range.setter
+    def range(self, rng: tuple[_V, _V]) -> None:
+        x0, x1 = rng
+        if x0 > x1:
+            raise ValueError(f"Minimum value exceeds maximum value ({x0} > {x1}).")
+        self._slider.setMinimum(x0)
+        self._slider.setMaximum(x1)
+
+    @property
+    def min(self) -> _V:
+        return self._slider.minimum()
+
+    @min.setter
+    def min(self, value: _V) -> None:
+        self._slider.setMinimum(value)
+
+    @property
+    def max(self) -> _V:
+        return self._slider.maximum()
+
+    @max.setter
+    def max(self, value: _V) -> None:
+        self._slider.setMaximum(value)
+
+
+class RangeSlider(AbstractRangeSlider[int]):
+    @classmethod
+    def _construct_qt(cls, *args, **kwargs):
+        from superqt import QLabeledRangeSlider
+
+        sl = QLabeledRangeSlider()
+        sl.setHandleLabelPosition(QLabeledRangeSlider.LabelPosition.LabelsAbove)
+        sl.setEdgeLabelMode(QLabeledRangeSlider.EdgeLabelMode.NoLabel)
+        return sl
+
+
+class FloatRangeSlider(AbstractRangeSlider[float]):
+    @classmethod
+    def _construct_qt(cls, *args, **kwargs):
+        from superqt import QLabeledDoubleRangeSlider
+
+        sl = QLabeledDoubleRangeSlider()
+        sl.setHandleLabelPosition(QLabeledDoubleRangeSlider.LabelPosition.LabelsAbove)
+        sl.setEdgeLabelMode(QLabeledDoubleRangeSlider.EdgeLabelMode.NoLabel)
+        return sl
+
+
 class _QtSpreadSheet(QTabWidget):
     def __init__(self):
         super().__init__()
